@@ -13,6 +13,11 @@ from . import arg_list
 
 LOG = logging.getLogger('pipeline_parallel.ProcessPool')
 
+# Correct bug in mac where default behavior from multiprocessing changed. This resulted in a Pickling error
+# probably due to the decorator I add to the call function
+# source: https://github.com/prompt-toolkit/ptpython/issues/193
+multiprocessing.set_start_method("fork")
+
 
 class ProcessPool(object):
     """
